with
  Ada.Streams,
  Ada.Strings.Unbounded;

package Chat is
   type User_ID is new Positive;
   type User_List is array (Positive range <>) of User_ID;

   type Connection_Type is access all Ada.Streams.Root_Stream_Type'Class;

   function Get_Current_Connection (User : User_ID) return Connection_Type;

   function Get_Friend_List (Source : Connection_Type) return User_List;

   function Random (From : in User_List) return User_ID
     with Pre => From'Length >= 1;

   type Received_Message is
      record
         From    : User_ID;
         Message : Ada.Strings.Unbounded.Unbounded_String;
      end record;

   procedure Send (Through : in Connection_Type;
                   Message : in Ada.Strings.Unbounded.Unbounded_String;
                   To      : in User_ID);
   function Receive (From : in Connection_Type) return Received_Message;

   function Random_Text (Sentences : in Natural)
                        return Ada.Strings.Unbounded.Unbounded_String;

   procedure Assert (Condition : in Boolean;
                     Message   : in String);
end Chat;
